@@ -47,7 +47,7 @@ else:
 
 from zmq.eventloop.zmqstream import ZMQStream
 
-from raphodo.rpdfile import (RPDFile, FileTypeCounter, FileSizeSum, Photo, Video)
+from raphodo.rpdfile import RPDFile, FileTypeCounter, FileSizeSum, Photo, Video
 from raphodo.devices import Device
 from raphodo.utilities import CacheDirs, set_pdeathsig
 from raphodo.constants import (
@@ -466,6 +466,12 @@ class LoadBalancerWorkerManager(ProcessManager):
         for worker_id in range(self.no_workers):
             self.add_worker(worker_id)
 
+    def zombie_workers(self) -> List[int]:
+        return [
+            worker_id for worker_id in self.workers
+            if self.processes[worker_id].status() == psutil.STATUS_ZOMBIE
+        ]
+
 
 class LRUQueue:
     """LRUQueue class using ZMQStream/IOLoop for event dispatching"""
@@ -516,6 +522,10 @@ class LRUQueue:
         # add worker back to the list of workers
         self.workers.append(worker_identity)
 
+        zw = self.process_manager.zombie_workers()
+        if zw:
+            logging.error("%s dead thumbnail extractors", len(zw))
+
         # Second frame is empty
         assert empty == b''
 
@@ -1107,9 +1117,9 @@ class LoadBalancerWorker:
         self.sender = self.context.socket(zmq.PUSH)
         self.sender.connect("tcp://localhost:{}".format(args.send))
         
-        self.logger_publisher = ProcessLoggerPublisher(context=self.context,
-                                                       name=worker_type,
-                                                       notification_port=args.logging)
+        self.logger_publisher = ProcessLoggerPublisher(
+            context=self.context, name=worker_type, notification_port=args.logging
+        )
 
         # Tell the load balancer we are ready for work
         self.requester.send(b"READY")
@@ -1268,7 +1278,8 @@ class ScanResults:
                  sample_video: Optional[Video]=None,
                  problems: Optional[ScanProblems]=None,
                  fatal_error: Optional[bool]=None,
-                 entire_video_required: Optional[bool]=None) -> None:
+                 entire_video_required: Optional[bool]=None,
+                 entire_photo_required: Optional[bool]=None) -> None:
         self.rpd_files = rpd_files
         self.file_type_counter = file_type_counter
         self.file_size_sum = file_size_sum
@@ -1282,6 +1293,7 @@ class ScanResults:
         self.problems = problems
         self.fatal_error = fatal_error
         self.entire_video_required = entire_video_required
+        self.entire_photo_required = entire_photo_required
 
 
 class CopyFilesArguments:
@@ -1492,12 +1504,14 @@ class GenerateThumbnailsArguments:
                  name: str,
                  proximity_seconds: int,
                  cache_dirs: CacheDirs,
+                 need_photo_cache_dir: bool,
                  need_video_cache_dir: bool,
                  frontend_port: int,
                  log_gphoto2: bool,
                  camera: Optional[str]=None,
                  port: Optional[str]=None,
-                 entire_video_required: Optional[bool]=None) -> None:
+                 entire_video_required: Optional[bool]=None,
+                 entire_photo_required: Optional[bool]=None) -> None:
         """
         List of files for which thumbnails are to be generated.
         All files  are assumed to have the same scan id.
@@ -1509,6 +1523,8 @@ class GenerateThumbnailsArguments:
          generation
         :param cache_dirs: the location where the cache directories
          should be created
+        :param need_photo_cache_dir: if True, must use cache dir
+         to extract photo thumbnail
         :param need_video_cache_dir: if True, must use cache dir
          to extract video thumbnail
         :param frontend_port: port to use to send to load balancer's
@@ -1518,8 +1534,10 @@ class GenerateThumbnailsArguments:
          camera, this is the name of the camera, else None
         :param port: If the thumbnails are being downloaded from a
          camera, this is the port of the camera, else None
-        :param entire_video_required:  if the entire video is
-         required to extract the thumbnail
+        :param entire_video_required: if the entire video is required
+         to extract the thumbnail
+        :param entire_photo_required: if the entire photo is required
+         to extract the thumbnail
         """
 
         self.rpd_files = rpd_files
@@ -1527,6 +1545,7 @@ class GenerateThumbnailsArguments:
         self.name = name
         self.proximity_seconds = proximity_seconds
         self.cache_dirs = cache_dirs
+        self.need_photo_cache_dir = need_photo_cache_dir
         self.need_video_cache_dir = need_video_cache_dir
         self.frontend_port = frontend_port
         if camera is not None:
@@ -1536,6 +1555,7 @@ class GenerateThumbnailsArguments:
         self.port = port
         self.log_gphoto2 = log_gphoto2
         self.entire_video_required = entire_video_required
+        self.entire_photo_required = entire_photo_required
 
 
 class GenerateThumbnailsResults:
@@ -1661,7 +1681,7 @@ class ScanManager(PublishPullPipelineManager):
     this computer path)
     """
     scannedFiles = pyqtSignal(
-        'PyQt_PyObject', 'PyQt_PyObject', FileTypeCounter, 'PyQt_PyObject', bool
+        'PyQt_PyObject', 'PyQt_PyObject', FileTypeCounter, 'PyQt_PyObject', bool, bool
     )
     deviceError = pyqtSignal(int, CameraErrorCode)
     deviceDetails = pyqtSignal(int, 'PyQt_PyObject', 'PyQt_PyObject', str)
@@ -1679,12 +1699,14 @@ class ScanManager(PublishPullPipelineManager):
             assert data.file_type_counter
             assert data.file_size_sum
             assert data.entire_video_required is not None
+            assert  data.entire_photo_required is not None
             self.scannedFiles.emit(
                 data.rpd_files,
                 (data.sample_photo, data.sample_video),
                 data.file_type_counter,
                 data.file_size_sum,
-                data.entire_video_required
+                data.entire_video_required,
+                data.entire_photo_required
             )
         else:
             assert data.scan_id is not None
